package com.ibm.esb.common;

/*
 * Modification History
 * Date       Author       Change#   Description
 * ----------------------------------------------------
 * 03/03/2019 Sudhakar     C000      Initial Version
*/
import java.io.BufferedReader;
import java.io.File;
//import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FilenameFilter;
import java.io.IOException;
import java.io.InputStreamReader;
//import java.io.LineNumberReader;
import java.io.StringReader;
import java.io.StringWriter;
import java.io.Writer;
import java.net.InetAddress;
import java.util.Calendar;
import java.util.Date;
import java.util.Enumeration;
import java.util.GregorianCalendar;
import java.util.Locale;
import java.util.Properties;

// Begin 2011-02-25 
// Added method to format/indent xml data
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import org.apache.xml.serialize.OutputFormat;
import org.apache.xml.serialize.XMLSerializer;
import org.w3c.dom.Document;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
// End 2011-02-25

import com.ibm.broker.plugin.MbTimestamp;
 
public class StaticMethods {

	public static String getHostName() {
		String hostname = null;
		try {
			hostname = InetAddress.getLocalHost().getHostName();
			//System.out.println("Hostname: " + hostname);			
		} catch (Exception e) {
			;
		}
		return hostname;
	}
	
	// The below method gets list of emails from an external file, and returns a string with all the emails separated by comma
	public static String getEmailsFromFile(String filename) {
		
		if (filename == null)
			return null;

		String line = null;
		BufferedReader reader = null;
		StringBuffer emails = new StringBuffer();
		
		try {
			reader = new BufferedReader(new FileReader(filename));
			int i=0;
			while ((line = reader.readLine()) != null) {
				if (i > 0)
					emails.append(",");
				emails.append((String) line );
				i++;
			}
		} catch (FileNotFoundException fnfe) {
			System.out.println("FILE NOT FOUND " + fnfe.getMessage());
		} catch (IOException ioe) {
			System.out.println("I/O Exception " + ioe.getMessage());
		} finally {
			try {
				if (reader != null)
					reader.close();
				reader = null;
			} catch (Exception e) {}
		}
		if (emails != null && emails.length() > 0)
			return emails.toString();
	
		return null;
	}
	
	public static String readTextFileToString(String filename) {
		
		String newline = System.getProperty("line.separator");
		
		if (filename == null)
			return null;

		String line = null;
		BufferedReader reader = null;
		StringBuffer content = new StringBuffer();
		
		try {
			reader = new BufferedReader(new FileReader(filename));
			while ((line = reader.readLine()) != null) {
				content.append((String) line );
				content.append( newline );
			}
		} catch (FileNotFoundException fnfe) {
			System.out.println("FILE NOT FOUND " + fnfe.getMessage());
		} catch (IOException ioe) {
			System.out.println("I/O Exception " + ioe.getMessage());
		} finally {
			try {
				if (reader != null)
					reader.close();
				reader = null;
			} catch (Exception e) {}
		}
		if (content != null && content.length() > 0)
			return content.toString();
	
		return null;
	}
	
	public static String getErrorCodesFromFile(String filename) {
		
		if (filename == null)
			return null;

		String line = null;
		BufferedReader reader = null;
		StringBuffer errorCodes = new StringBuffer();
		
		try {
			reader = new BufferedReader(new FileReader(filename));
			int i=0;
			while ((line = reader.readLine()) != null) {
				if (i > 0)
					errorCodes.append(",");
				errorCodes.append((String) line );
				i++;
			}
		} catch (FileNotFoundException fnfe) {
			System.out.println("FILE NOT FOUND " + fnfe.getMessage());
		} catch (IOException ioe) {
			System.out.println("I/O Exception " + ioe.getMessage());
		} finally {
			try {
				if (reader != null)
					reader.close();
				reader = null;
			} catch (Exception e) {}
		}
		if (errorCodes != null && errorCodes.length() > 0)
			return errorCodes.toString();
	
		return null;
	}
    
    public static String runCommand(String command) {
    	String out = "";
        try {
        	String osName = System.getProperty("os.name").toUpperCase();
      	
        	Runtime rt = Runtime.getRuntime();
        	Process p = null;
			
        	if (osName.indexOf("WINDOWS") >= 0)
			{
				p = rt.exec("cmd /c " + command);
        	}
			else {
				String cmd[] = { "/bin/sh", "-c", command};
				p = rt.exec(cmd);
			}
			
			if (p != null) {
				String line = null;
				BufferedReader in = new BufferedReader( new InputStreamReader(p.getInputStream()));  
				while ((line = in.readLine()) != null)  
					out += line;  
			}  
        } catch (Exception e) {
            e.printStackTrace();
        }
        return out;
    }
    // extract DEADQ name from output from "dis qmgr deadq | runmqsc qmgr" output
    public static String getDLQname(String str) {
    	String out = "";
        try {
        	int pos1 = str.indexOf("DEADQ(");
        	if (pos1 > 0) {
        		int pos2 = str.indexOf(')', pos1);
        		out = str.substring(pos1+6,pos2); 
        	}
        } catch (Exception e) {
            ;
        }
        return out;
    }
    
	public static MbTimestamp getCurrentTimestamp() {
		Date date = new Date(); // new Date() returns current timestamp
		Calendar cal = new GregorianCalendar();
        cal.setTime(date);
        MbTimestamp mbTimestamp = new MbTimestamp(cal.get(Calendar.YEAR), cal.get(Calendar.MONTH),
                cal.get(Calendar.DAY_OF_MONTH), cal.get(Calendar.HOUR_OF_DAY), cal.get(Calendar.MINUTE),
                cal.get(Calendar.SECOND), cal.get(Calendar.MILLISECOND));
        return mbTimestamp;
	}
	
	public static String getIso3Country(String iso2CountryCode){
	    Locale locale = new Locale("", iso2CountryCode);
	    String iso3CountryCode = locale.getISO3Country();
	    return iso3CountryCode;
	}

	// Get list of files that are older than "n" number of minutes
	/*
	 * Parms 
	 *    dirName : directory to look into
	 *    filenamefilter - filename to look 
	 *                        example: xyz.txt xyz*.txt
	 *    searchflag - "S", "E", "C"
	 *                  S=startsWith
	 *                  E=endsWith
	 *                  C=contains
	 *    Returns list of matching files separated by @#@#@
	 */
	public static String getFileListByTime(String dirName, final String filenamefilter, final String searchflag, String min) {
		
		File dir = new File(dirName);
		// int i = 0;
		StringBuffer sb = new StringBuffer(100);

		if (dir.isDirectory()) {

			 // create new filename filter
	         FilenameFilter fileNameFilter = new FilenameFilter() {
	   
	            @Override
	            public boolean accept(File dir, String name) {
	            	System.out.println("1");
	            	if (searchflag.equals("S")) {
	            		System.out.println("2");
	            		if (name.startsWith(filenamefilter) ) {
		            		return true;
	       		        }
	            	}
	            	else if (searchflag.equals("E")) {
	            		System.out.println("3");
	            		if (name.endsWith(filenamefilter) ) {
		            		return true;
	       		        }
	            	}
	            	else if (name.indexOf(filenamefilter) >= 0) {
	            		System.out.println("4");
	            		return true;
       		        }
	            	System.out.println("0");
       		        return false;
	            }
	         };
			
			String fileList[] = dir.list(fileNameFilter);

			for (int j = 0; j < fileList.length; j++) {
				String fileLocation = dirName + fileList[j];
				File f = new File(fileLocation);

				long l1 = f.lastModified();

				long l2 = System.currentTimeMillis();

				long timeDifference = l2 - l1;

				// Convert milliseconds to days.

				long seconds = timeDifference / 1000;
				long minutes = seconds / 60;
				// long hours = minutes / 60;
				// long days = hours / 24;
				int parmMinutes = Integer.parseInt(min);
				if (parmMinutes >= 0 && minutes >= parmMinutes) {
					try {
						if (sb.length() > 0)
							sb.append("@#@#@");	
						sb.append(fileList[j]);
						
					} catch (Exception e) {
						;
					}
				}
			}
		}
		return sb.toString();
	}
	

    public static String getParamValue(String s, String s1) {
        String s2 = null;
        try
            {
                FileInputStream fileinputstream = new FileInputStream(s);
                Properties properties = new Properties();
                properties.load(fileinputstream);
                fileinputstream.close();
                s2 = properties.getProperty(s1);
            } catch (IOException ioexception)
            {
                ioexception.printStackTrace();
            }
        return s2;
    }

}
